==> rgmining-fraudar-0.5.2.tar.gz: rgmining-fraudar-0.5.2/README.md <==
# A wrapper of FRAUDAR algorithm
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![Build Status](https://travis-ci.org/rgmining/fraudar.svg?branch=master)](https://travis-ci.org/rgmining/fraudar)
[![wercker status](https://app.wercker.com/status/0187c42cbf06f25156d1cc6bf6ca6ae8/s/master "wercker status")](https://app.wercker.com/project/byKey/0187c42cbf06f25156d1cc6bf6ca6ae8)
[![Code Climate](https://codeclimate.com/github/rgmining/fraudar/badges/gpa.svg)](https://codeclimate.com/github/rgmining/fraudar)
[![Release](https://img.shields.io/badge/release-0.5.2-brightgreen.svg)](https://github.com/rgmining/fraudar/releases/tag/v0.5.2)

This package implements a wrapper of
[FRAUDAR](https://www.andrew.cmu.edu/user/bhooi/projects/fraudar/index.html)
algorithm to provide APIs defined in
[Review Graph Mining project](https://rgmining.github.io/).


## Installation
Use `pip` to install this package.

```
$pip install --upgrade rgmining-fraudar
```


## License
This software is released under The GNU General Public License Version 3,
see [COPYING](COPYING) for more detail.

The original FRAUDAR source code, which is in `fraudar/export`, are made by
[Bryan Hooi](https://www.andrew.cmu.edu/user/bhooi/index.html),
[Hyun Ah Song](http://www.cs.cmu.edu/~hyunahs/),
[Alex Beutel](http://alexbeutel.com/),
[Neil Shah](http://www.cs.cmu.edu/~neilshah/),
[Kijung Shin](http://www.cs.cmu.edu/~kijungs/), and
[Christos Faloutsos](http://www.cs.cmu.edu/~christos/),
and licensed under [Apache License, Version 2.0](LICENSE-2.0).

==> rgmining-fraudar-0.6.0.tar.gz: rgmining-fraudar-0.6.0/README.md <==
# A wrapper of FRAUDAR algorithm
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![wercker status](https://app.wercker.com/status/0187c42cbf06f25156d1cc6bf6ca6ae8/s/master "wercker status")](https://app.wercker.com/project/byKey/0187c42cbf06f25156d1cc6bf6ca6ae8)
[![Code Climate](https://codeclimate.com/github/rgmining/fraudar/badges/gpa.svg)](https://codeclimate.com/github/rgmining/fraudar)
[![Release](https://img.shields.io/badge/release-0.6.0-brightgreen.svg)](https://github.com/rgmining/fraudar/releases/tag/v0.6.0)

This package implements a wrapper of
[FRAUDAR](https://www.andrew.cmu.edu/user/bhooi/projects/fraudar/index.html)
algorithm to provide APIs defined in
[Review Graph Mining project](https://rgmining.github.io/).


## Installation
Use `pip` to install this package.

```
$pip install --upgrade rgmining-fraudar
```


## License
This software is released under The GNU General Public License Version 3,
see [COPYING](COPYING) for more detail.

The original FRAUDAR source code is made by
[Bryan Hooi](https://www.andrew.cmu.edu/user/bhooi/index.html),
[Hyun Ah Song](http://www.cs.cmu.edu/~hyunahs/),
[Alex Beutel](http://alexbeutel.com/),
[Neil Shah](http://www.cs.cmu.edu/~neilshah/),
[Kijung Shin](http://www.cs.cmu.edu/~kijungs/), and
[Christos Faloutsos](http://www.cs.cmu.edu/~christos/),
and licensed under [Apache License, Version 2.0](LICENSE-2.0).
It is available at https://www.andrew.cmu.edu/user/bhooi/projects/fraudar/index.html.
